@@ -100,9 +100,11 @@
     {% do dbt_spark_validate_merge(file_format) %}
   {% endif %}
 
-  {% call statement() %}
-    set spark.sql.sources.partitionOverwriteMode = DYNAMIC
-  {% endcall %}
+  {% if config.get('partition_by') %}
+    {% call statement() %}
+      set spark.sql.sources.partitionOverwriteMode = DYNAMIC
+    {% endcall %}
+  {% endif %}
 
   {% call statement() %}
     set spark.sql.hive.convertMetastoreParquet = false
